import { render } from 'react-dom';
import './index.css';
/**
 * Sample for Zooming in chart
 */
import * as React from "react";
import { loadCldr, L10n, setCulture, setCurrencyCode } from '@syncfusion/ej2-base';
import * as currencies from './currencies.json';
import * as cagregorian from './ca-gregorian.json';
import * as numbers from './numbers.json';
import * as timeZoneNames from './timeZoneNames.json';

import { ChartComponent, SeriesCollectionDirective, SeriesDirective, Inject, AreaSeries, DateTime, Legend, Zoom, ScrollBar } from '@syncfusion/ej2-react-charts';
import { SampleBase } from './sample-base';
import { Browser } from '@syncfusion/ej2-base';

loadCldr(currencies, cagregorian, numbers, timeZoneNames);

setCulture('pt');
setCurrencyCode('BRL');

const SAMPLE_CSS = `
    #gradient-chart stop {
		stop-color: #BDEDE9;
	}
	#gradient-chart stop[offset="0"] {
		stop-opacity: 0.75;
	}
	#gradient-chart stop[offset="1"] {
		stop-opacity: 0;
	}`;
export function GetZoomingData() {
    let series1 = [];
    let point1;
    let value = 80;
    let i;
    for (i = 1; i < 500; i++) {
        if (Math.random() > .5) {
            value += Math.random();
        }
        else {
            value -= Math.random();
        }
        point1 = { x: new Date(1950, i + 2, i), y: value.toFixed(1) };
        series1.push(point1);
    }
    return { 'series1': series1 };
}
export let data = GetZoomingData().series1;
export class Zooming extends SampleBase {
    render() {
        return (<div className='control-pane'>
                <style>
                    {SAMPLE_CSS}
                </style>
                <div className='control-section'>
                    <ChartComponent id='charts' style={{ textAlign: "center" }} primaryXAxis={{
            title: 'Years',
            valueType: 'DateTime',
            edgeLabelPlacement: 'Shift',
            majorGridLines: { width: 0 }
        }}  primaryYAxis={{
            title: 'Profit ($)',
            labelFormat: 'c2',
            rangePadding: 'None',
            lineStyle: { width: 0 },
            majorTickLines: { width: 0 }
        }} width={Browser.isDevice ? '100%' : '80%'} chartArea={{ border: { width: 0 } }} legendSettings={{ visible: false }} zoomSettings={{
            enableMouseWheelZooming: true, enablePinchZooming: true,
            enableSelectionZooming: true, mode: 'X', enableScrollbar: true
        }} title='Sales History of Product X' loaded={this.onChartLoad.bind(this)}>
                        <Inject services={[AreaSeries, DateTime, Legend, Zoom, ScrollBar]}/>
                        <SeriesCollectionDirective>
                            <SeriesDirective dataSource={data} xName='x' yName='y' name='Product X' border={{ width: 0.5, color: '#00bdae' }} animation={{ enable: false }} fill='url(#gradient-chart)' type='Area'>
                            </SeriesDirective>
                        </SeriesCollectionDirective>
                    </ChartComponent>
                </div>
                <svg style={{ height: '0' }}>
                    <defs>
                        <linearGradient id="gradient-chart" x1="0" x2="0" y1="0" y2="1">
                            <stop offset="0"/>
                            <stop offset="1"/>
                        </linearGradient>
                    </defs>
                </svg>
            </div>);
    }
    onChartLoad(args) {
        let chart = document.getElementById('charts');
        chart.setAttribute('title', '');
    }
    ;
}

render(<Zooming />, document.getElementById('root'));